/*
 * CJsonComLayer.h
 *
 *
 *
 *
   Version History:
   2016-11-07 Ernst Murnleitner, Awite Bioenergie GmbH: Initial Version

 */

#ifndef CJSONCOMLAYER_H_
#define CJSONCOMLAYER_H_

#include "comlayer.h"
#include <commfb.h>
#include <string>
#include <vector>


namespace forte {
namespace com_infra {


enum EJsonDataType {
  json_auto, // let the system decide (e.g. json int fits to all int types, json bool fits to bool type etc.)
  json_any, // try to convert all types, e.g. true gives 1 for real, 1 for int, "true" for string, true for bool)
  json_string, // string, surrounded with quotes
  json_number, // a number, whichever fits best (real, int, bool)
  json_real, // always real number
  json_int, // always int number
  json_bool, // always bool number
  json_null
};

class CJsonComLayer: public CComLayer {
  public:
    CJsonComLayer(CComLayer* pa_poUpperLayer, CCommFB * pa_poFB);
    virtual ~CJsonComLayer();
    virtual void closeConnection();
    virtual EComResponse sendData( void *pa_pvData, unsigned int pa_unSize );
    virtual EComResponse recvData( const void *pa_pvData, unsigned int pa_unSize );
    virtual EComResponse processInterrupt();
    virtual EComResponse openConnection( char *pa_acLayerParameter );
  private:
    std::vector<std::string> m_jsonNameVector;
    // optionally a data type can be defined (json_auto by default)
    std::vector<EJsonDataType> m_jsonTypeVector;
    std::vector<std::vector<std::string >  > m_jsonHierarchyVectorVector;
};

} /* namespace com_infra */
} /* namespace forte */

#endif /* CJSONCOMLAYER_H_ */
